"""
city automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class City(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    state: Optional[str] = Field(default=None, alias="state")
    rb: Optional[str] = Field(default=None, alias="rb")
    district: Optional[str] = Field(default=None, alias="district")
    verb: Optional[str] = Field(default=None, alias="verb")
    gem: Optional[str] = Field(default=None, alias="gem")
    zip_code: Optional[str] = Field(default=None, alias="zipCode")
    area: Optional[int] = Field(default=None, alias="area")
    pass



"""
bundestag_member automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .bundestag_constituency import BundestagConstituency
class BundestagMember(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    party: Optional[str] = Field(default=None, alias="party")
    bio_url: Optional[str] = Field(default=None, alias="bioUrl")
    state: Optional[str] = Field(default=None, alias="state")
    constituency: Optional[BundestagConstituency] = Field(default=None, alias="constituency")
    elected: Optional[str] = Field(default=None, alias="elected")
    photo: Optional[str] = Field(default=None, alias="photo")
    photo_large: Optional[str] = Field(default=None, alias="photoLarge")
    photo_last_changed: Optional[datetime.datetime] = Field(default=None, alias="photoLastChanged")
    last_changed: Optional[datetime.datetime] = Field(default=None, alias="lastChanged")
    pass



"""
bundesrat_member automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class BundesratMember(BaseModel):
    honorific_title: Optional[str] = Field(default=None, alias="honorificTitle")
    first_name: Optional[str] = Field(default=None, alias="firstName")
    name: Optional[str] = Field(default=None, alias="name")
    party: Optional[str] = Field(default=None, alias="party")
    state: Optional[str] = Field(default=None, alias="state")
    bundesrat_member: Optional[bool] = Field(default=None, alias="bundesratMember")
    member: Optional[bool] = Field(default=None, alias="member")
    designated: Optional[bool] = Field(default=None, alias="designated")
    url: Optional[str] = Field(default=None, alias="url")
    image_path: Optional[str] = Field(default=None, alias="imagePath")
    image_date: Optional[datetime.datetime] = Field(default=None, alias="imageDate")
    detail: Optional[str] = Field(default=None, alias="detail")
    bio: Optional[str] = Field(default=None, alias="bio")
    address: Optional[str] = Field(default=None, alias="address")
    pass



"""
AutobahnTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .autobahn_charging_station_tag import AutobahnChargingStationTag
from .autobahn_closure_tag import AutobahnClosureTag
from .autobahn_collection import AutobahnCollection
from .autobahn_parking_lorry_tag import AutobahnParkingLorryTag
from .autobahn_warning_tag import AutobahnWarningTag
from .response_exception import ResponseException

class AutobahnTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def warning(self) -> AutobahnWarningTag:
        return AutobahnWarningTag(
            self.http_client,
            self.parser
        )

    def parking_lorry(self) -> AutobahnParkingLorryTag:
        return AutobahnParkingLorryTag(
            self.http_client,
            self.parser
        )

    def closure(self) -> AutobahnClosureTag:
        return AutobahnClosureTag(
            self.http_client,
            self.parser
        )

    def charging_station(self) -> AutobahnChargingStationTag:
        return AutobahnChargingStationTag(
            self.http_client,
            self.parser
        )


    def get_all(self) -> AutobahnCollection:
        """
        Returns all available autobahns
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/autobahn", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return AutobahnCollection.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise ResponseException(response.content)
            if response.status_code == 404:
                raise ResponseException(response.content)
            if response.status_code == 500:
                raise ResponseException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
BundestagTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .bundestag_member_tag import BundestagMemberTag

class BundestagTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def member(self) -> BundestagMemberTag:
        return BundestagMemberTag(
            self.http_client,
            self.parser
        )





"""
CityTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .city import City
from .city_collection import CityCollection
from .response_exception import ResponseException

class CityTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get(self, city_id: str) -> City:
        """
        Returns a specific city
        """
        try:
            path_params = {}
            path_params["city_id"] = city_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/city/:city_id", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return City.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise ResponseException(response.content)
            if response.status_code == 404:
                raise ResponseException(response.content)
            if response.status_code == 500:
                raise ResponseException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, start_index: int, state: str, district: str, name: str, zip_code: str) -> CityCollection:
        """
        Returns all available cities
        """
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["state"] = state
            query_params["district"] = district
            query_params["name"] = name
            query_params["zipCode"] = zip_code

            query_struct_names = []

            url = self.parser.url("/city", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CityCollection.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise ResponseException(response.content)
            if response.status_code == 404:
                raise ResponseException(response.content)
            if response.status_code == 500:
                raise ResponseException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
state automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class State(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    area: Optional[int] = Field(default=None, alias="area")
    pass



"""
warning_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .warning import Warning
class WarningCollection(BaseModel):
    entries: Optional[List[Warning]] = Field(default=None, alias="entries")
    pass



"""
autobahn_charging_station automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .autobahn_coordinate import AutobahnCoordinate
class AutobahnChargingStation(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    title: Optional[str] = Field(default=None, alias="title")
    description: Optional[List[str]] = Field(default=None, alias="description")
    coordinate: Optional[AutobahnCoordinate] = Field(default=None, alias="coordinate")
    pass



"""
warning automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class Warning(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    severity: Optional[str] = Field(default=None, alias="severity")
    urgency: Optional[str] = Field(default=None, alias="urgency")
    type: Optional[str] = Field(default=None, alias="type")
    title: Optional[str] = Field(default=None, alias="title")
    start_date: Optional[datetime.datetime] = Field(default=None, alias="startDate")
    expires_date: Optional[datetime.datetime] = Field(default=None, alias="expiresDate")
    pass



"""
Client automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .warning_tag import WarningTag
from .city_tag import CityTag
from .district_tag import DistrictTag
from .state_tag import StateTag
from .bundestag_tag import BundestagTag
from .bundesrat_tag import BundesratTag
from .autobahn_tag import AutobahnTag
from .authorization_tag import AuthorizationTag
from .meta_tag import MetaTag

class Client(sdkgen.ClientAbstract):
    def __init__(self, base_url: str, credentials: sdkgen.CredentialsInterface):
        super().__init__(base_url, credentials)

    def warning(self) -> WarningTag:
        return WarningTag(
            self.http_client,
            self.parser
        )

    def city(self) -> CityTag:
        return CityTag(
            self.http_client,
            self.parser
        )

    def district(self) -> DistrictTag:
        return DistrictTag(
            self.http_client,
            self.parser
        )

    def state(self) -> StateTag:
        return StateTag(
            self.http_client,
            self.parser
        )

    def bundestag(self) -> BundestagTag:
        return BundestagTag(
            self.http_client,
            self.parser
        )

    def bundesrat(self) -> BundesratTag:
        return BundesratTag(
            self.http_client,
            self.parser
        )

    def autobahn(self) -> AutobahnTag:
        return AutobahnTag(
            self.http_client,
            self.parser
        )

    def authorization(self) -> AuthorizationTag:
        return AuthorizationTag(
            self.http_client,
            self.parser
        )

    def meta(self) -> MetaTag:
        return MetaTag(
            self.http_client,
            self.parser
        )



    @staticmethod
    def build(clientId: str, clientSecret: str, tokenStore: sdkgen.TokenStoreInterface, scopes: List[str]):
        return Client("https://api.deutschland-api.dev/", sdkgen.OAuth2(clientId, clientSecret, "https://api.deutschland-api.dev/authorization/token", "", tokenStore, scopes))


    @staticmethod
    def buildAnonymous():
        return Client("https://api.deutschland-api.dev/", sdkgen.Anonymous())
